Module Name:    src
Committed By:   christos
Date:           Sun Jan 15 18:15:45 UTC 2017

Modified Files:
        src/common/lib/libprop: prop_kern.c

Log Message:
bump to 128K (because of npf large rules) and return E2BIG.


To generate a diff of this commit:
cvs rdiff -u -r1.19 -r1.20 src/common/lib/libprop/prop_kern.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/common/lib/libprop/prop_kern.c
diff -u src/common/lib/libprop/prop_kern.c:1.19 src/common/lib/libprop/prop_kern.c:1.20
--- src/common/lib/libprop/prop_kern.c:1.19	Mon May 11 12:48:34 2015
+++ src/common/lib/libprop/prop_kern.c	Sun Jan 15 13:15:45 2017
@@ -1,4 +1,4 @@
-/*	$NetBSD: prop_kern.c,v 1.19 2015/05/11 16:48:34 christos Exp $	*/
+/*	$NetBSD: prop_kern.c,v 1.20 2017/01/15 18:15:45 christos Exp $	*/
 
 /*-
  * Copyright (c) 2006, 2009 The NetBSD Foundation, Inc.
@@ -384,8 +384,8 @@ prop_dictionary_sendrecv_ioctl(prop_dict
 
 #include "prop_object_impl.h"
 
-/* Arbitrary limit ioctl input to 64KB */
-unsigned int prop_object_copyin_limit = 65536;
+/* Arbitrary limit ioctl input to 128KB */
+unsigned int prop_object_copyin_limit = 128 * 1024;
 
 /* initialize proplib for use in the kernel */
 void
@@ -408,7 +408,7 @@ _prop_object_copyin(const struct plistre
 	int error;
 
 	if (pref->pref_len >= prop_object_copyin_limit)
-		return EINVAL;
+		return E2BIG;
 
 	/*
 	 * Allocate an extra byte so we can guarantee NUL-termination.

Reply via email to